@@ -113,13 +113,13 @@ Dataset.data <- function(id, filters,  env = solvebio:::.solveEnv, ...) {
     if (missing(id) || !(class(id) %in% c("Dataset", "numeric", "integer", "character"))) {
         stop("A dataset ID (or object) is required.")
     }
-    if (class(id) == "Dataset" || class(id) == "Object") {
+    if (inherits(id, "Dataset") || inherits(id, "Object")) {
         id <- id$id
     }
     body = list(...)
     # Filters can be passed as a JSON string
     if (!missing(filters) && !is.null(filters) && length(filters) > 0) {
-        if (class(filters) == "character") {
+        if (inherits(filters, "character")) {
             # Convert JSON string to an R structure
             filters <- jsonlite::fromJSON(filters,
                                           simplifyVector = FALSE,
@@ -180,8 +180,7 @@ Dataset.query <- function(id, paginate=FALSE, use_field_titles=TRUE, env = solve
     while (isTRUE(paginate) && !is.null(offset)) {
         params$offset <- offset
         response <- do.call(Dataset.data, params)
-        df_page <- response$results
-        df <- dplyr::bind_rows(df, df_page)
+        df <- jsonlite::rbind_pages(list(df, response$results))
         offset <- response$offset
     }
 
@@ -213,7 +212,7 @@ Dataset.query <- function(id, paginate=FALSE, use_field_titles=TRUE, env = solve
 #'
 #' @export
 Dataset.fields <- function(id, env = solvebio:::.solveEnv, ...) {
-    if (class(id) == "numeric") {
+    if (inherits(id, "numeric")) {
         warning("Please use string IDs instead of numeric IDs.")
     }
 
@@ -221,7 +220,7 @@ Dataset.fields <- function(id, env = solvebio:::.solveEnv, ...) {
         stop("A dataset ID is required.")
     }
 
-    if (class(id) == "Dataset" || class(id) == "Object") {
+    if (inherits(id, "Dataset") || inherits(id, "Object")) {
         id <- id$id
     }
 
@@ -252,7 +251,7 @@ Dataset.facets <- function(id, facets, env = solvebio:::.solveEnv, ...) {
         stop("A list of one or more facets is required.")
     }
 
-    if (class(facets) == "character") {
+    if (inherits(facets, "character")) {
         if (grepl("[[{]", facets)) {
             # If it looks like JSON, try to convert to an R structure
             facets <- jsonlite::fromJSON(facets,
